@@ -298,7 +298,9 @@ def run_argument_parser(args):
 
     def make_unique_variant_kmers_single_thread(data):
         variants, args = data
-        args = object_from_shared_memory(args)
+        if isinstance(args, str):
+            logging.info("reading args from shared memory")
+            args = object_from_shared_memory(args)
         #variant_to_nodes = from_shared_memory(VariantToNodes, "variant_to_nodes_shared"+r)
         variant_to_nodes = args["variant_to_nodes"]
 
@@ -346,16 +348,21 @@ def run_argument_parser(args):
         n_threads = args["n_threads"]
 
         logging.info("Reading all variants")
-        pool = get_shared_pool(n_threads) #Pool(args["n_threads"])
         variants = VcfVariants.from_vcf(args["vcf"], skip_index=True, make_generator=True, dont_encode_chromosomes=True)
         variants = variants.get_chunks(chunk_size=args["chunk_size"])
 
         all_flat_kmers = []
-        args = object_to_shared_memory(args)
-        logging.info("Starting parallel")
-        #for flat_kmers in pool.imap(make_unique_variant_kmers_single_thread, zip(variants, repeat(args))):
-        for flat_kmers in chunked_imap(pool, make_unique_variant_kmers_single_thread, zip(variants, repeat(args)), chunk_size=n_threads*4):
-            all_flat_kmers.append(flat_kmers)
+        if n_threads == 1:
+            logging.info("Not running in paralell")
+            for chunk in variants:
+                all_flat_kmers.append(make_unique_variant_kmers_single_thread((chunk, args)))
+        else:
+            pool = get_shared_pool(n_threads) #Pool(args["n_threads"])
+            args = object_to_shared_memory(args)
+            logging.info("Starting parallel")
+            #for flat_kmers in pool.imap(make_unique_variant_kmers_single_thread, zip(variants, repeat(args))):
+            for flat_kmers in chunked_imap(pool, make_unique_variant_kmers_single_thread, zip(variants, repeat(args)), chunk_size=n_threads*4):
+                all_flat_kmers.append(flat_kmers)
 
         logging.info("Merge all flat kmers")
         merged_flat = FlatKmers.from_multiple_flat_kmers(all_flat_kmers)
